<?php

namespace App\Http\Controllers\Api;

use App\ConnectionSetting;
use App\Http\Requests\StoreConnectionSetting;
use App\Http\Controllers\Controller;
use App\Services\ApacheService;
use Illuminate\Http\Request;

class ConnectionSettingController extends Controller
{
    public function index(Request $request)
    {
        return ['data' => ConnectionSetting::byTenant($request->headers->get('tenant'))->get()];
    }

    public function store(StoreConnectionSetting $request)
    {
        $connectionSetting = ConnectionSetting::create($request->validated());
        
        ApacheService::generateFiles($connectionSetting, $request->input('tenant_path'));
    
        return ['data' => $connectionSetting];
    }

    public function show(ConnectionSetting $connectionSetting)
    {
        return ['data' => $connectionSetting];
    }

    public function update(StoreConnectionSetting $request, ConnectionSetting $connectionSetting)
    {
        $connectionSetting->update($request->validated());
        
        ApacheService::generateFiles($connectionSetting, $request->input('tenant_path'));
        
        return ['data' => $connectionSetting];
    }

    public function destroy(Request $request, ConnectionSetting $connectionSetting)
    {
        $validatedData = $request->validate([
            'tenant_path' => 'required'
        ]);

        ApacheService::deleteFiles($connectionSetting, $validatedData['tenant_path']);
    
        $connectionSetting->delete();
        
        return response()->json([], 204);
    }
}
