<?php

namespace App\Http\Controllers\Api;

use App\RingTone;
use App\Http\Controllers\Controller;
use App\Http\Requests\StoreRingTone;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Storage;

class RingToneController extends Controller
{
    public function index()
    {
        return ['data' => RingTone::all()];
    }

    public function store(StoreRingTone $request)
    {
        $validatedData = $request->validated();
        
        $ringtone = RingTone::create($validatedData);
        
        $this->uploadRingTones($validatedData['files'], $validatedData['folder']);
        
        return $ringtone;
    }

    public function update(StoreRingTone $request, RingTone $ringtone)
    {
        $validatedData = $request->validated();
        
        $ringtone->update($validatedData);
        
        $this->uploadRingTones($validatedData['files'], $validatedData['folder']);
        
        return $ringtone;
    }

    public function destroy(RingTone $ringtone)
    {
        Storage::disk('ringtones')->deleteDirectory($ringtone->folder);
        $ringtone->delete();
        
        return response()->json([], 204);
    }
    
    private function uploadRingTones($files, $folder)
    {
        foreach($files as $file) {
            Storage::disk('ringtones')->putFileAs($folder, $file, $file->getClientOriginalName());
        }
    }
}
